pub struct ConnectError(pub Box<dyn Error + Send + Sync>);Expand description
Wrapper type to indicate that an error occurs during the connection process, so that the appropriate gRPC Status can be inferred.
Tuple Fields
0: Box<dyn Error + Send + Sync>Trait Implementations
Sourceimpl Debug for ConnectError
impl Debug for ConnectError
Sourceimpl Display for ConnectError
impl Display for ConnectError
Sourceimpl Error for ConnectError
impl Error for ConnectError
Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0:
use the Display impl or to_string()