LayerExt

Trait LayerExt 

pub trait LayerExt<L>: Sealed {
    // Required method
    fn named_layer<S>(&self, service: S) -> Layered<L::Service, S>
       where L: Layer<S>;
}
Extension trait which adds utility methods to types which implement tower_layer::Layer.

Required Methods

fn named_layer<S>(&self, service: S) -> Layered<L::Service, S>
where L: Layer<S>,

Applies the layer to a service and wraps it in Layered.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<L> LayerExt<L> for L